package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcNetworkReport;

/**
 * 网络举报Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface TcNetworkReportMapper 
{
    /**
     * 查询网络举报
     * 
     * @param id 网络举报主键
     * @return 网络举报
     */
    public TcNetworkReport selectTcNetworkReportById(Long id);

    /**
     * 查询网络举报列表
     * 
     * @param tcNetworkReport 网络举报
     * @return 网络举报集合
     */
    public List<TcNetworkReport> selectTcNetworkReportList(TcNetworkReport tcNetworkReport);

    /**
     * 新增网络举报
     * 
     * @param tcNetworkReport 网络举报
     * @return 结果
     */
    public int insertTcNetworkReport(TcNetworkReport tcNetworkReport);

    /**
     * 修改网络举报
     * 
     * @param tcNetworkReport 网络举报
     * @return 结果
     */
    public int updateTcNetworkReport(TcNetworkReport tcNetworkReport);

    /**
     * 删除网络举报
     * 
     * @param id 网络举报主键
     * @return 结果
     */
    public int deleteTcNetworkReportById(Long id);

    /**
     * 批量删除网络举报
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcNetworkReportByIds(Long[] ids);
}
